v2.0 - Nautobot Design Builder Documentation

Skip to content

# v2.0.0 Release Notes

## Release Overview

The 2.0 release of design builder formally removes Nautobot 1.x support. Users requiring Nautobot 1.x support should pin their major version of Design Builder to 1.

## [v2.0.0] - 2024-05

### Removed

- Removed all unit tests for Nautobot 1.x

- Removed all conditionals utilizing the Nautobot version and replaced with relevant 2.x code.